@@ -83,7 +83,10 @@ class Spin_System:
             return temp
 
     def nos(self):
-        return len(self.spins)
+        if self.unordered:
+            return len(self.spins)
+        else:
+            return self.n_cells[0] * self.n_cells[1] * self.n_cells[2] * self.n_cell_atoms
 
     def center(self):
         return np.mean(self.flattened().positions, axis=0)
@@ -112,11 +115,11 @@ class Spin_System:
         result.unordered       = False
         return result.flattened()
 
-def spin_system_from_p_state(p_state, copy=False):
+def spin_system_from_p_state(p_state, idx_image=-1, copy=False):
     from spirit import geometry, system
     spin_system = Spin_System()
-    spin_system.positions     = geometry.get_positions(p_state)
-    spin_system.spins         = system.get_spin_directions(p_state)
+    spin_system.positions     = geometry.get_positions(p_state, idx_image = idx_image)
+    spin_system.spins         = system.get_spin_directions(p_state, idx_image = idx_image)
     spin_system.n_cell_atoms  = geometry.get_n_cell_atoms(p_state)
     spin_system.n_cells       = geometry.get_n_cells(p_state)
 
@@ -155,10 +158,21 @@ class energy_path:
         result = np.gradient(self.total_energy, self.reaction_coordinate)
         return result
 
+    def interpolated_slope(self):
+        result = np.gradient(self.interpolated_total_energy, self.interpolated_reaction_coordinate)
+        return result
+
     def curvature(self):
         result = np.gradient(self.slope(), self.reaction_coordinate)
         return result
 
+    def interpolated_curvature(self):
+        result = np.gradient(self.interpolated_slope(), self.interpolated_reaction_coordinate)
+        return result
+
+    def n_interpolated(self):
+        return int( ( len(self.interpolated_reaction_coordinate) - self.noi() ) / (self.noi() - 1) )
+
     def barrier(self):
         return np.max(self.total_energy) - self.total_energy[0]
 
